# Copyright 2022 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import api, fields, models


class SaleInterventionStock(models.Model):
    _name = "sale.intervention.stock"
    _description = "Stock d'interventions'"
    _order = "sale_order_id, project_id, categ_id, product_id"

    sale_intervention_id = fields.Many2one(
        comodel_name="sale.intervention",
        string="Intervention",
        ondelete="cascade",
        required=True,
    )

    # Related fields for display / analysis
    intervention_type_id = fields.Many2one(
        related="sale_intervention_id.intervention_type_id",
        string="Type d'intervention",
        store=True,
    )
    project_id = fields.Many2one(
        related="sale_intervention_id.project_id", string="Projet", store=True
    )
    saison_id = fields.Many2one(
        related="project_id.saison_id", string="Saison", store=True
    )
    partner_id = fields.Many2one(
        related="project_id.partner_id", string="Client", store=True
    )
    user_id = fields.Many2one(
        related="project_id.user_id", string="Référent", store=True
    )
    admin_state_id = fields.Many2one(
        related="project_id.admin_state_id", string="Étape du projet", store=True
    )
    advancement_ids = fields.Many2many(
        related="project_id.sale_project_advancement_ids", string="Avancement"
    )
    plants_qty = fields.Integer(
        related="sale_intervention_id.plants_qty",
        string="Nb de plants",
        store=True,
        group_operator="sum",
    )
    intervention_length = fields.Float(
        related="sale_intervention_id.intervention_length",
        string="Longueur haie",
        group_operator="sum",
        store=True,
    )
    surface = fields.Integer(
        related="sale_intervention_id.surface",
        string="Surface",
        group_operator="sum",
        store=True,
    )

    sale_order_id = fields.Many2one(
        related="project_id.sale_order_id",
        string="Devis/Commande",
        store=True,
    )
    product_id = fields.Many2one(
        "product.product",
        string="Product",
        required=True,
        change_default=True,
        ondelete="restrict",
    )
    product_template_id = fields.Many2one(related="product_id.product_tmpl_id")
    name = fields.Char(string="Article", related="product_id.name")
    categ_id = fields.Many2one(related="product_template_id.categ_id", store=True)
    product_uom_qty = fields.Float(
        string="Quantité",
        digits="Product Unit of Measure",
        required=True,
        default=1.0,
        group_operator="sum",
    )
    price_unit = fields.Float(
        "Prix Unitaire", required=True, digits="Product Price", default=0.0
    )
    price_total = fields.Float(
        compute="_compute_amount",
        string="Prix Total",
        readonly=True,
        store=True,
        group_operator="sum",
    )

    @api.depends("product_uom_qty", "price_unit")
    def _compute_amount(self):
        for rec in self:
            rec.price_total = rec.product_uom_qty * rec.price_unit
