# Copyright 2021 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import fields, models


class SaleOrder(models.Model):
    _inherit = "sale.order"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    sale_project_ids = fields.One2many(
        comodel_name="sale.project",
        inverse_name="sale_order_id",
        string="Projets",
        readonly=True,
        states={"draft": [("readonly", False)], "sent": [("readonly", False)]},
    )
    sale_intervention_stock_ids = fields.One2many(
        comodel_name="sale.intervention.stock",
        inverse_name="sale_order_id",
        string="Articles d'interventions'",
    )

    # ------------------------------------------------------
    # Business method
    # ------------------------------------------------------
    def clean_sale_order(self):
        inter_list = list()
        for project in self.sale_project_ids:
            for inter in project.intervention_ids:
                inter_list.append(
                    (project.id, inter.intervention_type_id.product_variant_id.id)
                )
        for sol in self.order_line:
            if (
                sol.sale_project_id
                and sol.product_id
                and (sol.sale_project_id.id, sol.product_id.id) not in inter_list
            ):
                sol.unlink()

    def action_print_pdf(self):
        if self.state == "draft":
            self.write({"state": "sent"})
        return self.env.ref("sale.action_report_saleorder").report_action(self)
